<?php
namespace Render3D\Site\BlockLayout;

use Omeka\Api\Representation\SiteRepresentation;
use Omeka\Api\Representation\SitePageRepresentation;
use Omeka\Api\Representation\SitePageBlockRepresentation;
use Omeka\Site\BlockLayout\AbstractBlockLayout;
use Laminas\View\Renderer\PhpRenderer;

use Laminas\Form\FormElementManager;

use Render3D\Form\Render3DBlockForm;

class Render3D extends AbstractBlockLayout
{
	/**
     * @var FormElementManager
     */
    protected $formElementManager;

    /**
     * @var array
     */
	protected $defaultSettings = [];

    /**
     * @param FormElementManager $formElementManager
     * @param array $defaultSettings
     */
    public function __construct(FormElementManager $formElementManager, array $defaultSettings)
    {
        $this->formElementManager = $formElementManager;
        $this->defaultSettings = $defaultSettings;
    }

	public function getLabel() {
		return '3D Renderer';
	}

	public function form(PhpRenderer $view,
                       SiteRepresentation $site,
                       SitePageRepresentation $page = null,
                       SitePageBlockRepresentation $block = null
    ) {
		$form = $this->formElementManager->get(Render3DBlockForm::class);
		$data = $block
			? $block->data() + $this->defaultSettings
			: $this->defaultSettings;
		$form->setData([
			'o:block[__blockIndex__][o:data][model_type]' => $data['model_type'],
			'o:block[__blockIndex__][o:data][title]' => $data['title'],
			'o:block[__blockIndex__][o:data][width]' => $data['width'],
			'o:block[__blockIndex__][o:data][ratio]' => $data['ratio'],
      'o:block[__blockIndex__][o:data][renderSourceLink]' => $data['renderSourceLink'],
      //'o:block[__blockIndex__][o:data][addPreLoadImage]' => $data['addPreLoadImage'],
		]);
		$form->prepare();

		$html = '';
		$html .= $view->blockAttachmentsForm($block);
		$html .= '<a href="#" class="collapse" aria-label="collapse"><h4>' . $view->translate('Options'). '</h4></a>';
		$html .= '<div class="collapsible" style="padding-top:6px;">';
		$html .= $view->formCollection($form);
        $html .= '</div>';
		return $html;
    }

	public function render(PhpRenderer $view, SitePageBlockRepresentation $block)
	{
		$attachments = $block->attachments();
        if (!$attachments) {
            return '';
		}

		$urls = [];
    $media_types = [];
    $thumbnails = [];
    $model_type = $block->dataValue('model_type');
		static $id = 0;

		foreach ($attachments as $attachment)
		{
			foreach($attachment->item()->media() as $media)
			{
				$mediaType = $media->mediaType();
				$mediaRenderer = $media->renderer();

        array_push($urls, $media->originalUrl());
				array_push($media_types, $mediaType);
        array_push($thumbnails, $media->thumbnailUrls());
			}
		}
    $width = $block->dataValue('width');
    $height = $width;
    $skybox = null;
    foreach($urls as $url) {
      if (strpos($url, "sky-box-image")) {
        $skybox = $url;
      }
    }
		return $view->partial('common/block-layout/render-3d', [
			'model_type' => $model_type,
			'title' => $block->dataValue('title'),
			'width' => $width,
			'ratio' => $block->dataValue('ratio'),
			'height' => $height,
      'item_url' => $attachments[0]->item()->url(),
      'renderSourceLink' => $block->dataValue('renderSourceLink'),
      'addPreLoadImage' => 1,
      'skybox' => $skybox,
			'urls' => $urls,
      'id' => 'v3d-' . ++$id,
      'mediaTypes' => $media_types,
      'thumbnails' => $thumbnails,
		]);
	}
}
